Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(122)

Unified Diff: webkit/plugins/ppapi/ppapi_plugin_instance.h

Issue 10912060: Allow the NaCl IPC proxy to support multiple instances. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webkit/plugins/ppapi/plugin_module.cc ('k') | webkit/plugins/ppapi/ppapi_plugin_instance.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webkit/plugins/ppapi/ppapi_plugin_instance.h
===================================================================
--- webkit/plugins/ppapi/ppapi_plugin_instance.h (revision 154817)
+++ webkit/plugins/ppapi/ppapi_plugin_instance.h (working copy)
@@ -468,7 +468,7 @@
// proxy and re-sends DidCreate, DidChangeView, and HandleDocumentLoad (if
// necessary).
// This is for use with the NaCl proxy.
- bool ResetAsProxied();
+ bool ResetAsProxied(scoped_refptr<PluginModule> module);
private:
// Implements PPB_Gamepad_API. This is just to avoid having an excessive
@@ -572,10 +572,11 @@
PluginDelegate* delegate_;
scoped_refptr<PluginModule> module_;
scoped_ptr< ::ppapi::PPP_Instance_Combined> instance_interface_;
- // If this is the NaCl plugin, store its instance interface so we can shut
- // it down properly when using the IPC-based PPAPI proxy.
- // TODO(bbudge) Remove this when the proxy switch is complete.
- scoped_ptr< ::ppapi::PPP_Instance_Combined> nacl_plugin_instance_interface_;
+ // If this is the NaCl plugin, we create a new module when we switch to the
+ // IPC-based PPAPI proxy. Store the original module and instance interface
+ // so we can shut down properly.
+ scoped_refptr<PluginModule> original_module_;
+ scoped_ptr< ::ppapi::PPP_Instance_Combined> original_instance_interface_;
PP_Instance pp_instance_;
« no previous file with comments | « webkit/plugins/ppapi/plugin_module.cc ('k') | webkit/plugins/ppapi/ppapi_plugin_instance.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698